@@ -40,11 +40,20 @@ def params_only_method(name: str, age: int) -> dict:
     return {name: age}
 
 
+# Unioned primitives
+def unioned_primitives(foo: int, bar: str = 'auto_bar') -> dict:
+    return {'foo': foo, 'bar': bar}
+
+
 # No input artifacts or parameters.
 def no_input_method() -> dict:
     return {'foo': 42}
 
 
+def deprecated_method() -> dict:
+    return {'foo': 43}
+
+
 def long_description_method(mapping1: dict, name: str, age: int) -> dict:
     return {name: age}
 
