@@ -96,21 +96,6 @@ class TestInvalidMetadataColumnConstruction(unittest.TestCase):
                 [1, 2, 3], name='',
                 index=pd.Index(['a', 'b', 'c'], name='id')))
 
-    def test_leading_trailing_whitespace_id(self):
-        with self.assertRaisesRegex(ValueError, "metadata ID.*leading or "
-                                                "trailing whitespace.*' b '"):
-            DummyMetadataColumn(pd.Series(
-                [1, 2, 3], name='col',
-                index=pd.Index(['a', ' b ', 'c'], name='id')))
-
-    def test_leading_trailing_whitespace_column_name(self):
-        with self.assertRaisesRegex(
-                ValueError, "metadata column name.*leading or trailing "
-                            "whitespace.*' col2 '"):
-            DummyMetadataColumn(pd.Series(
-                [1, 2, 3], name=' col2 ',
-                index=pd.Index(['a', 'b', 'c'], name='id')))
-
     def test_pound_sign_id(self):
         with self.assertRaisesRegex(
                 ValueError, "metadata ID.*begins with a pound sign.*'#b'"):
@@ -826,14 +811,6 @@ class TestCategoricalMetadataColumn(unittest.TestCase):
                 ['foo', '', 'bar'], name='col1',
                 index=pd.Index(['a', 'b', 'c'], name='id')))
 
-    def test_leading_trailing_whitespace_value(self):
-        with self.assertRaisesRegex(
-                ValueError, "CategoricalMetadataColumn.*leading or trailing "
-                            "whitespace characters.*Column 'col1'.*' bar '"):
-            CategoricalMetadataColumn(pd.Series(
-                ['foo', ' bar ', 'baz'], name='col1',
-                index=pd.Index(['a', 'b', 'c'], name='id')))
-
     def test_type_property(self):
         self.assertEqual(CategoricalMetadataColumn.type, 'categorical')
 
@@ -899,6 +876,36 @@ class TestCategoricalMetadataColumn(unittest.TestCase):
         pdt.assert_series_equal(obs, exp)
         self.assertEqual(obs.dtype, object)
 
+    def test_leading_trailing_whitespace_value(self):
+        col1 = CategoricalMetadataColumn(pd.Series(
+            ['foo', ' bar ', 'baz'], name='col1',
+            index=pd.Index(['a', 'b', 'c'], name='id')))
+        col2 = CategoricalMetadataColumn(pd.Series(
+            ['foo', 'bar', 'baz'], name='col1',
+            index=pd.Index(['a', 'b', 'c'], name='id')))
+
+        self.assertEqual(col1, col2)
+
+    def test_leading_trailing_whitespace_id(self):
+        col1 = CategoricalMetadataColumn(pd.Series(
+                ['foo', ' bar ', 'baz'], name='col',
+                index=pd.Index(['a', ' b ', 'c'], name='id')))
+        col2 = CategoricalMetadataColumn(pd.Series(
+                ['foo', ' bar ', 'baz'], name='col',
+                index=pd.Index(['a', 'b', 'c'], name='id')))
+
+        self.assertEqual(col1, col2)
+
+    def test_leading_trailing_whitespace_column_name(self):
+        col1 = CategoricalMetadataColumn(pd.Series(
+                ['foo', ' bar ', 'baz'], name=' col ',
+                index=pd.Index(['a', 'b', 'c'], name='id')))
+        col2 = CategoricalMetadataColumn(pd.Series(
+                ['foo', ' bar ', 'baz'], name='col',
+                index=pd.Index(['a', 'b', 'c'], name='id')))
+
+        self.assertEqual(col1, col2)
+
 
 class TestNumericMetadataColumn(unittest.TestCase):
     def test_unsupported_dtype(self):
