@@ -90,7 +90,10 @@ class TestPlugin(unittest.TestCase):
                           'combinatorically_mapped_method',
                           'double_bound_variable_method',
                           'bool_flag_swaps_output_method',
-                          'predicates_preserved_method'})
+                          'predicates_preserved_method',
+                          'deprecated_method',
+                          'unioned_primitives',
+                          })
         for action in actions.values():
             self.assertIsInstance(action, qiime2.sdk.Action)
 
@@ -118,7 +121,10 @@ class TestPlugin(unittest.TestCase):
                           'combinatorically_mapped_method',
                           'double_bound_variable_method',
                           'bool_flag_swaps_output_method',
-                          'predicates_preserved_method'})
+                          'predicates_preserved_method',
+                          'deprecated_method',
+                          'unioned_primitives',
+                          })
         for method in methods.values():
             self.assertIsInstance(method, qiime2.sdk.Method)
 
