@@ -237,10 +237,12 @@ class Artifact(Result):
             format_ = view_type
 
         provenance_capture = archive.ImportProvenanceCapture(format_, md5sums)
-        return cls._from_view(type_, view, view_type, provenance_capture)
+        return cls._from_view(type_, view, view_type, provenance_capture,
+                              validate_level='max')
 
     @classmethod
-    def _from_view(cls, type, view, view_type, provenance_capture):
+    def _from_view(cls, type, view, view_type, provenance_capture,
+                   validate_level='min'):
         if isinstance(type, str):
             type = qiime2.sdk.parse_type(type)
 
@@ -262,7 +264,7 @@ class Artifact(Result):
         recorder = provenance_capture.transformation_recorder('return')
         transformation = from_type.make_transformation(to_type,
                                                        recorder=recorder)
-        result = transformation(view)
+        result = transformation(view, validate_level)
 
         artifact = cls.__new__(cls)
         artifact._archiver = archive.Archiver.from_data(
